@@ -1,6 +1,6 @@
 --GregorioTeX Lua file.
 --
---Copyright (C) 2008-2017 The Gregorio Project (see CONTRIBUTORS.md)
+--Copyright (C) 2008-2019 The Gregorio Project (see CONTRIBUTORS.md)
 --
 --This file is part of Gregorio.
 --
@@ -24,16 +24,16 @@ local hpack, traverse, traverse_id, has_attribute, count, remove, insert_after,
 gregoriotex = gregoriotex or {}
 local gregoriotex = gregoriotex
 
-local internalversion = '5.0.2' -- GREGORIO_VERSION (comment used by VersionManager.py)
+local internalversion = '5.2.0' -- GREGORIO_VERSION (comment used by VersionManager.py)
 
 local err, warn, info, log = luatexbase.provides_module({
     name               = "gregoriotex",
-    version            = '5.0.2', -- GREGORIO_VERSION
+    version            = '5.2.0', -- GREGORIO_VERSION
     greinternalversion = internalversion,
-    date               = "2017/05/24", -- GREGORIO_DATE_LTX
+    date               = "2019/03/10", -- GREGORIO_DATE_LTX
     description        = "GregorioTeX module.",
     author             = "The Gregorio Project (see CONTRIBUTORS.md)",
-    copyright          = "2008-2017 - The Gregorio Project",
+    copyright          = "2008-2019 - The Gregorio Project",
     license            = "GPLv3+",
 })
 
@@ -146,7 +146,7 @@ local function gregorio_exe()
     local exe_version
 
     -- first look for one with the exact version
-    real_gregorio_exe = 'gregorio-5_0_2' -- FILENAME_VERSION
+    real_gregorio_exe = 'gregorio-5_2_0' -- FILENAME_VERSION
     local cmd = string.format("%s -o %%s %s", real_gregorio_exe,
         test_snippet_filename)
     exe_version = get_prog_output(cmd, '*line')
@@ -901,6 +901,8 @@ local function include_score(input_file, force_gabccompile, allow_deprecated)
   -- open the gabc file for reading so that LuaTeX records input from it
   -- when the -recorder option is used; do this here so that this happens
   -- on every run
+  tex.sprint(catcode_at_letter, string.format(
+      [[\openin\gre@read@temp=%s\relax\closein\gre@read@temp]], gabc_file))
   local gabc = io.open(gabc_file, 'r')
   if gabc == nil then
     err("\n Unable to open %s", gabc_file)
@@ -1094,8 +1096,8 @@ local function change_score_glyph(glyph_name, font_name, replacement, cavum)
   cavum = cavum or ''
   if string.match(glyph_name, '%*') then
     glyph_name = '^'..glyph_name:gsub('%*', '.*')..'$'
-    if not string.match(replacement, '^%.') then
-      err('If a wildcard is supplied for glyph name, replacement must start with a dot.')
+    if replacement ~= '' and not string.match(replacement, '^%.') then
+      err('If a wildcard is supplied for glyph name, replacement must be blank or start with a dot.')
     end
     local general_font = general_font_for(cavum)
     local other_font
